Struct Interrupts
Source pub struct Interrupts { }
Returns the “default value” for a type.
Read more
The size of the object if saved now, note that this might change, for example
due to the length of string objects or data inside the object.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.